/*
 * Copyright (C) 2010, Center for Adaptive Behaviour and Cognition (ABC).
 * Developer: Martijn Brakenhoff 
 * 
 * Max Planck Institute for Human Development
 * (Max-Planck-Institut fr Bildungsforschung)
 * Lentzeallee 94, 14195 Berlin
 * Germany 
 */
package eu.larkc.jactr.core.chunk.rdf;

import org.jactr.core.chunk.ISymbolicChunk;
import org.openrdf.model.Resource;

import eu.larkc.core.data.LabelledGroupOfStatements;

/**
 * Symbolic chunks that implement this interface contain RDF data. 
 * 
 * @author Martijn Brakenhoff
 * @created March 10, 2010
 */
public interface ISymbolicChunkRdf extends ISymbolicChunk {
	  
	public static final String RDF_SLOT_NAME = "rdf";
	
	/**
	 * Set the RDF Data to be the given LabelledGroupOfStatements  
	 * 
	 * @param statements The labelled group of statements that 
	 * contain information for this chunk.
	 */
	public void setRdfData(LabelledGroupOfStatements statements);
	
	/**
	 * Retrieve the RDF Data stored in this Chunk.  
	 * 
	 * @return the data stored in this chunk. 
	 */
	public LabelledGroupOfStatements getRdfData();
	
	/**
	 * Retrieve the RDF Resource that represents this Chunk.  
	 * 
	 * @return the chunk-resource. 
	 */
	public Resource getChunkResource();
}


