/*
 * Copyright (C) 2010, Center for Adaptive Behaviour and Cognition (ABC).
 * Developer: Martijn Brakenhoff 
 * 
 * Max Planck Institute for Human Development
 * (Max-Planck-Institut fr Bildungsforschung)
 * Lentzeallee 94, 14195 Berlin
 * Germany 
 */
package eu.larkc.jactr.modules.sparql;

import java.util.Collection;
import java.util.Collections;
import java.util.concurrent.Callable;
import java.util.concurrent.Future;

import org.apache.commons.logging.Log;
import org.apache.commons.logging.LogFactory;
import org.jactr.core.buffer.IActivationBuffer;
import org.jactr.core.chunk.IChunk;
import org.jactr.core.module.retrieval.buffer.DefaultRetrievalBuffer6;
import org.jactr.core.module.retrieval.four.IRetrievalModule4;
import org.jactr.core.production.request.ChunkTypeRequest;
import org.openrdf.model.URI;
import org.openrdf.model.impl.URIImpl;

import eu.larkc.core.data.SPARQLEndpoint;
import eu.larkc.core.query.RemoteSPARQLEndpoint;
import eu.larkc.jactr.modules.sparql.ISPARQLRetrievalModule;

/**
 * The default retrieval module for retrieving chunks from the a Remote SPARQLEndpoint.
 * 
 * @author Martijn Brakenhoff
 * @created April 14, 2010
 */
public class RemoteSPARQLEndpointRetrievalModule extends AbstractSPARQLRetrievalModule
		implements ISPARQLRetrievalModule, IRetrievalModule4 {

	private static final transient Log 	LOGGER = LogFactory.getLog(RemoteSPARQLEndpointRetrievalModule.class);
	
	private static final String ENDPOINT_URL = "EndpointUrl";
	private DefaultRetrievalBuffer6 _retrievalBuffer;
	private SPARQLEndpoint endpoint;
	private URI endpointUrl;

	@Override
	protected Collection<IActivationBuffer> createBuffers() {
		_retrievalBuffer = new DefaultRetrievalBuffer6(getName(), this);
	    return Collections.singleton((IActivationBuffer) _retrievalBuffer);
	}
	
	@Override
	public Future<IChunk> retrieveChunk(final ChunkTypeRequest chunkPattern) {
		return delayedFuture(new Callable<IChunk>() {

			public IChunk call() throws Exception {
				return retrieveChunk(createSPARQLRequest(chunkPattern)).get();
			}

		}, getExecutor());
	}

	@Override
	public SPARQLEndpoint getSPARQLEndpoint() {
		return endpoint;
	}
	
	protected void setSPARQLEndpoint(SPARQLEndpoint endpoint) {
		this.endpoint = endpoint;
	}

	private URI getEndpointUrl() {
		return endpointUrl;
	}

	private void setEndpointURL(String endpointUrl) {
		this.endpointUrl = new URIImpl(endpointUrl);
	}
	
	public String getParameter(String key) {
		if (ENDPOINT_URL.equalsIgnoreCase(key)) {
    		return getEndpointUrl().toString();
		}
		return super.getParameter(key);
	}

	public Collection<String> getSetableParameters() {
		Collection<String> rtn = super.getSetableParameters();
		rtn.add(ENDPOINT_URL);
		return rtn;
	}
	
	public void setParameter(String key, String value) {
		if (LOGGER.isDebugEnabled()) {
			LOGGER.debug("Module Parameter set: "+ key +"="+ value);
		}
		
		if ( ENDPOINT_URL.equalsIgnoreCase(key) ) {
			setEndpointURL( value );
			RemoteSPARQLEndpoint endpoint = new RemoteSPARQLEndpoint(getEndpointUrl());
			setSPARQLEndpoint(endpoint);
		} else { 
			super.setParameter(key, value);
		}
	}
}
