/*
 * Copyright (C) 2010, Center for Adaptive Behaviour and Cognition (ABC).
 * Developer: Martijn Brakenhoff 
 * 
 * Max Planck Institute for Human Development
 * (Max-Planck-Institut fr Bildungsforschung)
 * Lentzeallee 94, 14195 Berlin
 * Germany 
 */
package eu.larkc.jactr.scripting.sparql;

import org.apache.commons.lang.NotImplementedException;

import org.jactr.scripting.IScriptableFactory;
import org.jactr.scripting.action.IActionScript;
import org.jactr.scripting.condition.IConditionScript;

/**
 * A ScriptableFactory for using SPARQL in jACT-R scripts.
 * 
 * @author Martijn Brakenhoff
 * @created April 10, 2010
 */
public class SPARQLFactory implements IScriptableFactory {

	public IActionScript createActionScript(String script) throws Exception {
		return new SPARQLAction(script, this);
	}

	public IConditionScript createConditionScript(String script) throws Exception {
		return new SPARQLCondition(script, this);
	}

	public String getDescription() {
		return "SPARQL Protocol And RDF Querying Language";
	}

	public String getLanguageName() {
		return "sparql";
	}

	public Object getGlobalContext() {
		throw new NotImplementedException();
	}

	public Object getVariable(String label, Object variableContext) {
		throw new NotImplementedException();
	}
	
	public void setVariable(String label, Object value, Object variableContext) {
		throw new NotImplementedException();
	}
	
	public boolean supports(String scriptName) {
		return scriptName.equalsIgnoreCase("sparql");
	}
}
